package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module ContentAdsSettings.BackupOptionSource

Sourcetype t = {
  1. color : string;
    (*

    Color to use when type is set to COLOR.

    *)
  2. _type : string;
    (*

    Type of the backup option. Possible values are BLANK, COLOR and URL.

    *)
  3. url : string;
    (*

    URL to use when type is set to URL.

    *)
}
Sourceval color : (t, string) GapiLens.t
Sourceval _type : (t, string) GapiLens.t
Sourceval url : (t, string) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list