package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiBigqueryV2Model.JobStatistics3Source

Sourcetype t = {
  1. inputFileBytes : int64;
    (*

    [Output-only] Number of bytes of source data in a load job.

    *)
  2. inputFiles : int64;
    (*

    [Output-only] Number of source files in a load job.

    *)
  3. outputBytes : int64;
    (*

    [Output-only] Size of the loaded data in bytes. Note that while a load job is in the running state, this value may change.

    *)
  4. outputRows : int64;
    (*

    [Output-only] Number of rows imported in a load job. Note that while an import job is in the running state, this value may change.

    *)
}
Sourceval inputFileBytes : (t, int64) GapiLens.t
Sourceval inputFiles : (t, int64) GapiLens.t
Sourceval outputBytes : (t, int64) GapiLens.t
Sourceval outputRows : (t, int64) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t