package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiCalendarV3Model.FreeBusyRequestSource

Sourcetype t = {
  1. timeMax : GapiDate.t;
    (*

    The end of the interval for the query formatted as per RFC3339.

    *)
  2. timeZone : string;
    (*

    Time zone used in the response. Optional. The default is UTC.

    *)
  3. calendarExpansionMax : int;
    (*

    Maximal number of calendars for which FreeBusy information is to be provided. Optional. Maximum value is 50.

    *)
  4. timeMin : GapiDate.t;
    (*

    The start of the interval for the query formatted as per RFC3339.

    *)
  5. groupExpansionMax : int;
    (*

    Maximal number of calendar identifiers to be provided for a single group. Optional. An error is returned for a group with more members than this value. Maximum value is 100.

    *)
  6. items : FreeBusyRequestItem.t list;
    (*

    List of calendars and/or groups to query.

    *)
}
Sourceval timeMax : (t, GapiDate.t) GapiLens.t
Sourceval timeZone : (t, string) GapiLens.t
Sourceval calendarExpansionMax : (t, int) GapiLens.t
Sourceval timeMin : (t, GapiDate.t) GapiLens.t
Sourceval groupExpansionMax : (t, int) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t