package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module App.IconsSource

Sourcetype t = {
  1. category : string;
    (*

    Category of the icon. Allowed values are:

    • application - icon for the application
    • document - icon for a file associated with the app
    • documentShared - icon for a shared file associated with the app
    *)
  2. iconUrl : string;
    (*

    URL for the icon.

    *)
  3. size : int;
    (*

    Size of the icon. Represented as the maximum of the width and height.

    *)
}
Sourceval category : (t, string) GapiLens.t
Sourceval iconUrl : (t, string) GapiLens.t
Sourceval size : (t, int) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list