package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiDriveV2Model.CommentReplySource

Sourcetype t = {
  1. author : User.t;
    (*

    The user who wrote this reply.

    *)
  2. content : string;
    (*

    The plain text content used to create this reply. This is not HTML safe and should only be used as a starting point to make edits to a reply's content. This field is required on inserts if no verb is specified (resolve/reopen).

    *)
  3. createdDate : GapiDate.t;
    (*

    The date when this reply was first created.

    *)
  4. deleted : bool;
    (*

    Whether this reply has been deleted. If a reply has been deleted the content will be cleared and this will only represent a reply that once existed.

    *)
  5. htmlContent : string;
    (*

    HTML formatted content for this reply.

    *)
  6. kind : string;
    (*

    This is always drive#commentReply.

    *)
  7. modifiedDate : GapiDate.t;
    (*

    The date when this reply was last modified.

    *)
  8. replyId : string;
    (*

    The ID of the reply.

    *)
  9. verb : string;
    (*

    The action this reply performed to the parent comment. When creating a new reply this is the action to be perform to the parent comment. Possible values are:

    • "resolve" - To resolve a comment.
    • "reopen" - To reopen (un-resolve) a comment.
    *)
}
Sourceval author : (t, User.t) GapiLens.t
Sourceval content : (t, string) GapiLens.t
Sourceval createdDate : (t, GapiDate.t) GapiLens.t
Sourceval deleted : (t, bool) GapiLens.t
Sourceval htmlContent : (t, string) GapiLens.t
Sourceval kind : (t, string) GapiLens.t
Sourceval modifiedDate : (t, GapiDate.t) GapiLens.t
Sourceval replyId : (t, string) GapiLens.t
Sourceval verb : (t, string) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t