package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module File.ImageMediaMetadataSource

Sourcemodule Location : sig ... end
Sourcetype t = {
  1. aperture : float;
    (*

    The aperture used to create the photo (f-number).

    *)
  2. cameraMake : string;
    (*

    The make of the camera used to create the photo.

    *)
  3. cameraModel : string;
    (*

    The model of the camera used to create the photo.

    *)
  4. colorSpace : string;
    (*

    The color space of the photo.

    *)
  5. date : string;
    (*

    The date and time the photo was taken (EXIF format timestamp).

    *)
  6. exposureBias : float;
    (*

    The exposure bias of the photo (APEX value).

    *)
  7. exposureMode : string;
    (*

    The exposure mode used to create the photo.

    *)
  8. exposureTime : float;
    (*

    The length of the exposure, in seconds.

    *)
  9. flashUsed : bool;
    (*

    Whether a flash was used to create the photo.

    *)
  10. focalLength : float;
    (*

    The focal length used to create the photo, in millimeters.

    *)
  11. height : int;
    (*

    The height of the image in pixels.

    *)
  12. isoSpeed : int;
    (*

    The ISO speed used to create the photo.

    *)
  13. lens : string;
    (*

    The lens used to create the photo.

    *)
  14. location : Location.t;
    (*

    Geographic location information stored in the image.

    *)
  15. maxApertureValue : float;
    (*

    The smallest f-number of the lens at the focal length used to create the photo (APEX value).

    *)
  16. meteringMode : string;
    (*

    The metering mode used to create the photo.

    *)
  17. rotation : int;
    (*

    The rotation in clockwise degrees from the image's original orientation.

    *)
  18. sensor : string;
    (*

    The type of sensor used to create the photo.

    *)
  19. subjectDistance : int;
    (*

    The distance to the subject of the photo, in meters.

    *)
  20. whiteBalance : string;
    (*

    The white balance mode used to create the photo.

    *)
  21. width : int;
    (*

    The width of the image in pixels.

    *)
}
Sourceval aperture : (t, float) GapiLens.t
Sourceval cameraMake : (t, string) GapiLens.t
Sourceval cameraModel : (t, string) GapiLens.t
Sourceval colorSpace : (t, string) GapiLens.t
Sourceval date : (t, string) GapiLens.t
Sourceval exposureBias : (t, float) GapiLens.t
Sourceval exposureMode : (t, string) GapiLens.t
Sourceval exposureTime : (t, float) GapiLens.t
Sourceval flashUsed : (t, bool) GapiLens.t
Sourceval focalLength : (t, float) GapiLens.t
Sourceval height : (t, int) GapiLens.t
Sourceval isoSpeed : (t, int) GapiLens.t
Sourceval lens : (t, string) GapiLens.t
Sourceval location : (t, Location.t) GapiLens.t
Sourceval maxApertureValue : (t, float) GapiLens.t
Sourceval meteringMode : (t, string) GapiLens.t
Sourceval rotation : (t, int) GapiLens.t
Sourceval sensor : (t, string) GapiLens.t
Sourceval subjectDistance : (t, int) GapiLens.t
Sourceval whiteBalance : (t, string) GapiLens.t
Sourceval width : (t, int) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list