package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiDriveV2Model.RevisionSource

Sourcetype t = {
  1. downloadUrl : string;
    (*

    Short term download URL for the file. This will only be populated on files with content stored in Drive.

    *)
  2. etag : string;
    (*

    The ETag of the revision.

    *)
  3. fileSize : int64;
    (*

    The size of the revision in bytes. This will only be populated on files with content stored in Drive.

    *)
  4. id : string;
    (*

    The ID of the revision.

    *)
  5. kind : string;
    (*

    This is always drive#revision.

    *)
  6. lastModifyingUser : User.t;
    (*

    The last user to modify this revision.

    *)
  7. lastModifyingUserName : string;
    (*

    Name of the last user to modify this revision.

    *)
  8. md5Checksum : string;
    (*

    An MD5 checksum for the content of this revision. This will only be populated on files with content stored in Drive.

    *)
  9. mimeType : string;
    (*

    The MIME type of the revision.

    *)
  10. modifiedDate : GapiDate.t;
    (*

    Last time this revision was modified (formatted RFC 3339 timestamp).

    *)
  11. originalFilename : string;
    (*

    The original filename when this revision was created. This will only be populated on files with content stored in Drive.

    *)
  12. pinned : bool;
    (*

    Whether this revision is pinned to prevent automatic purging. This will only be populated and can only be modified on files with content stored in Drive which are not Google Docs. Revisions can also be pinned when they are created through the drive.files.insert/update/copy by using the pinned query parameter.

    *)
  13. publishAuto : bool;
    (*

    Whether subsequent revisions will be automatically republished. This is only populated and can only be modified for Google Docs.

    *)
  14. published : bool;
    (*

    Whether this revision is published. This is only populated and can only be modified for Google Docs.

    *)
  15. publishedOutsideDomain : bool;
    (*

    Whether this revision is published outside the domain. This is only populated and can only be modified for Google Docs.

    *)
}
Sourceval downloadUrl : (t, string) GapiLens.t
Sourceval etag : (t, string) GapiLens.t
Sourceval fileSize : (t, int64) GapiLens.t
Sourceval id : (t, string) GapiLens.t
Sourceval kind : (t, string) GapiLens.t
Sourceval lastModifyingUser : (t, User.t) GapiLens.t
Sourceval lastModifyingUserName : (t, string) GapiLens.t
Sourceval md5Checksum : (t, string) GapiLens.t
Sourceval mimeType : (t, string) GapiLens.t
Sourceval modifiedDate : (t, GapiDate.t) GapiLens.t
Sourceval originalFilename : (t, string) GapiLens.t
Sourceval pinned : (t, bool) GapiLens.t
Sourceval publishAuto : (t, bool) GapiLens.t
Sourceval published : (t, bool) GapiLens.t
Sourceval publishedOutsideDomain : (t, bool) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t