package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiDriveV2Service.ScopeSource

Service Auth Scopes

Sourceval drive : string

View and manage the files in your Google Drive

Sourceval drive_appdata : string

View and manage its own configuration data in your Google Drive

Sourceval drive_apps_readonly : string

View your Google Drive apps

Sourceval drive_file : string

View and manage Google Drive files and folders that you have opened or created with this app

Sourceval drive_metadata : string

View and manage metadata of files in your Google Drive

Sourceval drive_metadata_readonly : string

View metadata for files in your Google Drive

Sourceval drive_photos_readonly : string

View the photos, videos and albums in your Google Photos

Sourceval drive_readonly : string

View the files in your Google Drive

Sourceval drive_scripts : string

Modify your Google Apps Script scripts' behavior