package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiDriveV3Model.AppSource

Sourcetype t = {
  1. name : string;
    (*

    The name of the app.

    *)
  2. objectType : string;
    (*

    The type of object this app creates such as a Chart. If empty, the app name should be used instead.

    *)
  3. supportsCreate : bool;
    (*

    Whether this app supports creating objects.

    *)
  4. productUrl : string;
    (*

    A link to the product listing for this app.

    *)
  5. primaryMimeTypes : string list;
    (*

    The list of primary MIME types.

    *)
  6. secondaryMimeTypes : string list;
    (*

    The list of secondary MIME types.

    *)
  7. primaryFileExtensions : string list;
    (*

    The list of primary file extensions.

    *)
  8. secondaryFileExtensions : string list;
    (*

    The list of secondary file extensions.

    *)
  9. id : string;
    (*

    The ID of the app.

    *)
  10. supportsImport : bool;
    (*

    Whether this app supports importing from Google Docs.

    *)
  11. installed : bool;
    (*

    Whether the app is installed.

    *)
  12. authorized : bool;
    (*

    Whether the app is authorized to access data on the user's Drive.

    *)
  13. icons : AppIcons.t list;
    (*

    The various icons for the app.

    *)
  14. useByDefault : bool;
    (*

    Whether the app is selected as the default handler for the types it supports.

    *)
  15. kind : string;
    (*

    Output only. Identifies what kind of resource this is. Value: the fixed string "drive#app".

    *)
  16. shortDescription : string;
    (*

    A short description of the app.

    *)
  17. longDescription : string;
    (*

    A long description of the app.

    *)
  18. supportsMultiOpen : bool;
    (*

    Whether this app supports opening more than one file.

    *)
  19. productId : string;
    (*

    The ID of the product listing for this app.

    *)
  20. openUrlTemplate : string;
    (*

    The template URL for opening files with this app. The template contains {ids} or {exportIds} to be replaced by the actual file IDs. For more information, see Open Files for the full documentation.

    *)
  21. createUrl : string;
    (*

    The URL to create a file with this app.

    *)
  22. createInFolderTemplate : string;
    (*

    The template URL to create a file with this app in a given folder. The template contains the {folderId} to be replaced by the folder ID house the new file.

    *)
  23. supportsOfflineCreate : bool;
    (*

    Whether this app supports creating files when offline.

    *)
  24. hasDriveWideScope : bool;
    (*

    Whether the app has Drive-wide scope. An app with Drive-wide scope can access all files in the user's Drive.

    *)
}
Sourceval name : (t, string) GapiLens.t
Sourceval objectType : (t, string) GapiLens.t
Sourceval supportsCreate : (t, bool) GapiLens.t
Sourceval productUrl : (t, string) GapiLens.t
Sourceval primaryMimeTypes : (t, string list) GapiLens.t
Sourceval secondaryMimeTypes : (t, string list) GapiLens.t
Sourceval primaryFileExtensions : (t, string list) GapiLens.t
Sourceval secondaryFileExtensions : (t, string list) GapiLens.t
Sourceval id : (t, string) GapiLens.t
Sourceval supportsImport : (t, bool) GapiLens.t
Sourceval installed : (t, bool) GapiLens.t
Sourceval authorized : (t, bool) GapiLens.t
Sourceval icons : (t, AppIcons.t list) GapiLens.t
Sourceval useByDefault : (t, bool) GapiLens.t
Sourceval kind : (t, string) GapiLens.t
Sourceval shortDescription : (t, string) GapiLens.t
Sourceval longDescription : (t, string) GapiLens.t
Sourceval supportsMultiOpen : (t, bool) GapiLens.t
Sourceval productId : (t, string) GapiLens.t
Sourceval openUrlTemplate : (t, string) GapiLens.t
Sourceval createUrl : (t, string) GapiLens.t
Sourceval createInFolderTemplate : (t, string) GapiLens.t
Sourceval supportsOfflineCreate : (t, bool) GapiLens.t
Sourceval hasDriveWideScope : (t, bool) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t