package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module File.ShortcutDetailsSource

Sourcetype t = {
  1. targetId : string;
    (*

    The ID of the file that this shortcut points to. Can only be set on `files.create` requests.

    *)
  2. targetMimeType : string;
    (*

    Output only. The MIME type of the file that this shortcut points to. The value of this field is a snapshot of the target's MIME type, captured when the shortcut is created.

    *)
  3. targetResourceKey : string;
    (*

    Output only. The ResourceKey for the target file.

    *)
}
Sourceval targetId : (t, string) GapiLens.t
Sourceval targetMimeType : (t, string) GapiLens.t
Sourceval targetResourceKey : (t, string) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list