package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiDriveV3Model.ReplySource

Sourcetype t = {
  1. id : string;
    (*

    Output only. The ID of the reply.

    *)
  2. kind : string;
    (*

    Output only. Identifies what kind of resource this is. Value: the fixed string `"drive#reply"`.

    *)
  3. createdTime : GapiDate.t;
    (*

    The time at which the reply was created (RFC 3339 date-time).

    *)
  4. modifiedTime : GapiDate.t;
    (*

    The last time the reply was modified (RFC 3339 date-time).

    *)
  5. action : string;
    (*

    The action the reply performed to the parent comment. Valid values are: * `resolve` * `reopen`

    *)
  6. author : User.t;
    (*

    Output only. The author of the reply. The author's email address and permission ID will not be populated.

    *)
  7. deleted : bool;
    (*

    Output only. Whether the reply has been deleted. A deleted reply has no content.

    *)
  8. htmlContent : string;
    (*

    Output only. The content of the reply with HTML formatting.

    *)
  9. content : string;
    (*

    The plain text content of the reply. This field is used for setting the content, while `htmlContent` should be displayed. This is required on creates if no `action` is specified.

    *)
}
Sourceval id : (t, string) GapiLens.t
Sourceval kind : (t, string) GapiLens.t
Sourceval createdTime : (t, GapiDate.t) GapiLens.t
Sourceval modifiedTime : (t, GapiDate.t) GapiLens.t
Sourceval action : (t, string) GapiLens.t
Sourceval author : (t, User.t) GapiLens.t
Sourceval deleted : (t, bool) GapiLens.t
Sourceval htmlContent : (t, string) GapiLens.t
Sourceval content : (t, string) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t