package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module TeamDrive.RestrictionsSource

Sourcetype t = {
  1. copyRequiresWriterPermission : bool;
    (*

    Whether the options to copy, print, or download files inside this Team Drive, should be disabled for readers and commenters. When this restriction is set to `true`, it will override the similarly named field to `true` for any file inside this Team Drive.

    *)
  2. domainUsersOnly : bool;
    (*

    Whether access to this Team Drive and items inside this Team Drive is restricted to users of the domain to which this Team Drive belongs. This restriction may be overridden by other sharing policies controlled outside of this Team Drive.

    *)
  3. teamMembersOnly : bool;
    (*

    Whether access to items inside this Team Drive is restricted to members of this Team Drive.

    *)
  4. adminManagedRestrictions : bool;
    (*

    Whether administrative privileges on this Team Drive are required to modify restrictions.

    *)
  5. sharingFoldersRequiresOrganizerPermission : bool;
    (*

    If true, only users with the organizer role can share folders. If false, users with either the organizer role or the file organizer role can share folders.

    *)
  6. downloadRestriction : DownloadRestriction.t;
    (*

    Download restrictions applied by shared drive managers.

    *)
}
Sourceval copyRequiresWriterPermission : (t, bool) GapiLens.t
Sourceval domainUsersOnly : (t, bool) GapiLens.t
Sourceval teamMembersOnly : (t, bool) GapiLens.t
Sourceval adminManagedRestrictions : (t, bool) GapiLens.t
Sourceval sharingFoldersRequiresOrganizerPermission : (t, bool) GapiLens.t
Sourceval downloadRestriction : (t, DownloadRestriction.t) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list