package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiDriveV3Service.AccessproposalsResourceSource

Sourceval get : ?base_url:string -> ?etag:string -> ?std_params:GapiService.StandardParameters.t -> ?custom_headers:GapiCore.Header.t list -> fileId:string -> proposalId:string -> GapiConversation.Session.t -> GapiDriveV3Model.AccessProposal.t * GapiConversation.Session.t

Retrieves an AccessProposal by ID.

  • parameter base_url

    Service endpoint base URL (defaults to "https://www.googleapis.com/drive/v3/").

  • parameter etag

    Optional ETag.

  • parameter std_params

    Optional standard parameters.

  • parameter custom_headers

    Optional HTTP custom headers.

  • parameter fileId

    Required. The id of the item the request is on.

  • parameter proposalId

    Required. The id of the access proposal to resolve.

Sourceval resolve : ?base_url:string -> ?std_params:GapiService.StandardParameters.t -> ?custom_headers:GapiCore.Header.t list -> fileId:string -> proposalId:string -> GapiDriveV3Model.ResolveAccessProposalRequest.t -> GapiConversation.Session.t -> unit * GapiConversation.Session.t

Used to approve or deny an Access Proposal.

  • parameter base_url

    Service endpoint base URL (defaults to "https://www.googleapis.com/drive/v3/").

  • parameter std_params

    Optional standard parameters.

  • parameter custom_headers

    Optional HTTP custom headers.

  • parameter fileId

    Required. The id of the item the request is on.

  • parameter proposalId

    Required. The id of the access proposal to resolve.

Sourceval list : ?base_url:string -> ?std_params:GapiService.StandardParameters.t -> ?custom_headers:GapiCore.Header.t list -> ?pageToken:string -> ?pageSize:int -> fileId:string -> GapiConversation.Session.t -> GapiDriveV3Model.ListAccessProposalsResponse.t * GapiConversation.Session.t

List the AccessProposals on a file. Note: Only approvers are able to list AccessProposals on a file. If the user is not an approver, returns a 403.

  • parameter base_url

    Service endpoint base URL (defaults to "https://www.googleapis.com/drive/v3/").

  • parameter std_params

    Optional standard parameters.

  • parameter custom_headers

    Optional HTTP custom headers.

  • parameter pageToken

    Optional. The continuation token on the list of access requests.

  • parameter pageSize

    Optional. The number of results per page

  • parameter fileId

    Required. The id of the item the request is on.