package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiDriveV3Service.ChangesResourceSource

Sourceval getStartPageToken : ?base_url:string -> ?std_params:GapiService.StandardParameters.t -> ?custom_headers:GapiCore.Header.t list -> ?supportsAllDrives:bool -> ?supportsTeamDrives:bool -> ?driveId:string -> ?teamDriveId:string -> GapiConversation.Session.t -> GapiDriveV3Model.StartPageToken.t * GapiConversation.Session.t

Gets the starting pageToken for listing future changes. For more information, see [Retrieve changes](https://developers.google.com/workspace/drive/api/guides/manage-changes).

  • parameter base_url

    Service endpoint base URL (defaults to "https://www.googleapis.com/drive/v3/").

  • parameter std_params

    Optional standard parameters.

  • parameter custom_headers

    Optional HTTP custom headers.

  • parameter supportsAllDrives

    Whether the requesting application supports both My Drives and shared drives.

  • parameter supportsTeamDrives

    Deprecated: Use `supportsAllDrives` instead.

  • parameter driveId

    The ID of the shared drive for which the starting pageToken for listing future changes from that shared drive will be returned.

  • parameter teamDriveId

    Deprecated: Use `driveId` instead.

Sourceval list : ?base_url:string -> ?std_params:GapiService.StandardParameters.t -> ?custom_headers:GapiCore.Header.t list -> ?includeCorpusRemovals:bool -> ?includeItemsFromAllDrives:bool -> ?includeRemoved:bool -> ?includeTeamDriveItems:bool -> ?pageSize:int -> ?restrictToMyDrive:bool -> ?spaces:string -> ?supportsAllDrives:bool -> ?supportsTeamDrives:bool -> ?driveId:string -> ?teamDriveId:string -> ?includePermissionsForView:string -> ?includeLabels:string -> pageToken:string -> GapiConversation.Session.t -> GapiDriveV3Model.ChangeList.t * GapiConversation.Session.t

Lists the changes for a user or shared drive. For more information, see [Retrieve changes](https://developers.google.com/workspace/drive/api/guides/manage-changes).

  • parameter base_url

    Service endpoint base URL (defaults to "https://www.googleapis.com/drive/v3/").

  • parameter std_params

    Optional standard parameters.

  • parameter custom_headers

    Optional HTTP custom headers.

  • parameter includeCorpusRemovals

    Whether changes should include the file resource if the file is still accessible by the user at the time of the request, even when a file was removed from the list of changes and there will be no further change entries for this file.

  • parameter includeItemsFromAllDrives

    Whether both My Drive and shared drive items should be included in results.

  • parameter includeRemoved

    Whether to include changes indicating that items have been removed from the list of changes, for example by deletion or loss of access.

  • parameter includeTeamDriveItems

    Deprecated: Use `includeItemsFromAllDrives` instead.

  • parameter pageSize

    The maximum number of changes to return per page.

  • parameter restrictToMyDrive

    Whether to restrict the results to changes inside the My Drive hierarchy. This omits changes to files such as those in the Application Data folder or shared files which have not been added to My Drive.

  • parameter spaces

    A comma-separated list of spaces to query within the corpora. Supported values are 'drive' and 'appDataFolder'.

  • parameter supportsAllDrives

    Whether the requesting application supports both My Drives and shared drives.

  • parameter supportsTeamDrives

    Deprecated: Use `supportsAllDrives` instead.

  • parameter driveId

    The shared drive from which changes will be returned. If specified the change IDs will be reflective of the shared drive; use the combined drive ID and change ID as an identifier.

  • parameter teamDriveId

    Deprecated: Use `driveId` instead.

  • parameter includePermissionsForView

    Specifies which additional view's permissions to include in the response. Only 'published' is supported.

  • parameter includeLabels

    A comma-separated list of IDs of labels to include in the `labelInfo` part of the response.

  • parameter pageToken

    The token for continuing a previous list request on the next page. This should be set to the value of 'nextPageToken' from the previous response or to the response from the getStartPageToken method.

Sourceval watch : ?base_url:string -> ?std_params:GapiService.StandardParameters.t -> ?custom_headers:GapiCore.Header.t list -> ?includeCorpusRemovals:bool -> ?includeItemsFromAllDrives:bool -> ?includeRemoved:bool -> ?includeTeamDriveItems:bool -> ?pageSize:int -> ?restrictToMyDrive:bool -> ?spaces:string -> ?supportsAllDrives:bool -> ?supportsTeamDrives:bool -> ?driveId:string -> ?teamDriveId:string -> ?includePermissionsForView:string -> ?includeLabels:string -> pageToken:string -> GapiDriveV3Model.Channel.t -> GapiConversation.Session.t -> GapiDriveV3Model.Channel.t * GapiConversation.Session.t

Subscribes to changes for a user. For more information, see [Notifications for resource changes](https://developers.google.com/workspace/drive/api/guides/push).

  • parameter base_url

    Service endpoint base URL (defaults to "https://www.googleapis.com/drive/v3/").

  • parameter std_params

    Optional standard parameters.

  • parameter custom_headers

    Optional HTTP custom headers.

  • parameter includeCorpusRemovals

    Whether changes should include the file resource if the file is still accessible by the user at the time of the request, even when a file was removed from the list of changes and there will be no further change entries for this file.

  • parameter includeItemsFromAllDrives

    Whether both My Drive and shared drive items should be included in results.

  • parameter includeRemoved

    Whether to include changes indicating that items have been removed from the list of changes, for example by deletion or loss of access.

  • parameter includeTeamDriveItems

    Deprecated: Use `includeItemsFromAllDrives` instead.

  • parameter pageSize

    The maximum number of changes to return per page.

  • parameter restrictToMyDrive

    Whether to restrict the results to changes inside the My Drive hierarchy. This omits changes to files such as those in the Application Data folder or shared files which have not been added to My Drive.

  • parameter spaces

    A comma-separated list of spaces to query within the corpora. Supported values are 'drive' and 'appDataFolder'.

  • parameter supportsAllDrives

    Whether the requesting application supports both My Drives and shared drives.

  • parameter supportsTeamDrives

    Deprecated: Use `supportsAllDrives` instead.

  • parameter driveId

    The shared drive from which changes will be returned. If specified the change IDs will be reflective of the shared drive; use the combined drive ID and change ID as an identifier.

  • parameter teamDriveId

    Deprecated: Use `driveId` instead.

  • parameter includePermissionsForView

    Specifies which additional view's permissions to include in the response. Only 'published' is supported.

  • parameter includeLabels

    A comma-separated list of IDs of labels to include in the `labelInfo` part of the response.

  • parameter pageToken

    The token for continuing a previous list request on the next page. This should be set to the value of 'nextPageToken' from the previous response or to the response from the getStartPageToken method.