package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiDriveV3Service.PermissionsResourceSource

Sourceval create : ?base_url:string -> ?std_params:GapiService.StandardParameters.t -> ?custom_headers:GapiCore.Header.t list -> ?enforceSingleParent:bool -> ?moveToNewOwnersRoot:bool -> ?supportsAllDrives:bool -> ?supportsTeamDrives:bool -> ?transferOwnership:bool -> ?useDomainAdminAccess:bool -> ?enforceExpansiveAccess:bool -> ?emailMessage:string -> ?sendNotificationEmail:bool -> fileId:string -> GapiDriveV3Model.Permission.t -> GapiConversation.Session.t -> GapiDriveV3Model.Permission.t * GapiConversation.Session.t

Creates a permission for a file or shared drive. **Warning:** Concurrent permissions operations on the same file are not supported; only the last update is applied.

  • parameter base_url

    Service endpoint base URL (defaults to "https://www.googleapis.com/drive/v3/").

  • parameter std_params

    Optional standard parameters.

  • parameter custom_headers

    Optional HTTP custom headers.

  • parameter enforceSingleParent

    Deprecated: See `moveToNewOwnersRoot` for details.

  • parameter moveToNewOwnersRoot

    This parameter will only take effect if the item is not in a shared drive and the request is attempting to transfer the ownership of the item. If set to `true`, the item will be moved to the new owner's My Drive root folder and all prior parents removed. If set to `false`, parents are not changed.

  • parameter supportsAllDrives

    Whether the requesting application supports both My Drives and shared drives.

  • parameter supportsTeamDrives

    Deprecated: Use `supportsAllDrives` instead.

  • parameter transferOwnership

    Whether to transfer ownership to the specified user and downgrade the current owner to a writer. This parameter is required as an acknowledgement of the side effect.

  • parameter useDomainAdminAccess

    Issue the request as a domain administrator; if set to true, then the requester will be granted access if the file ID parameter refers to a shared drive and the requester is an administrator of the domain to which the shared drive belongs.

  • parameter enforceExpansiveAccess

    Whether the request should enforce expansive access rules.

  • parameter emailMessage

    A plain text custom message to include in the notification email.

  • parameter sendNotificationEmail

    Whether to send a notification email when sharing to users or groups. This defaults to true for users and groups, and is not allowed for other requests. It must not be disabled for ownership transfers.

  • parameter fileId

    The ID of the file or shared drive.

Sourceval delete : ?base_url:string -> ?std_params:GapiService.StandardParameters.t -> ?custom_headers:GapiCore.Header.t list -> ?supportsAllDrives:bool -> ?supportsTeamDrives:bool -> ?useDomainAdminAccess:bool -> ?enforceExpansiveAccess:bool -> fileId:string -> permissionId:string -> GapiConversation.Session.t -> unit * GapiConversation.Session.t

Deletes a permission. **Warning:** Concurrent permissions operations on the same file are not supported; only the last update is applied.

  • parameter base_url

    Service endpoint base URL (defaults to "https://www.googleapis.com/drive/v3/").

  • parameter std_params

    Optional standard parameters.

  • parameter custom_headers

    Optional HTTP custom headers.

  • parameter supportsAllDrives

    Whether the requesting application supports both My Drives and shared drives.

  • parameter supportsTeamDrives

    Deprecated: Use `supportsAllDrives` instead.

  • parameter useDomainAdminAccess

    Issue the request as a domain administrator; if set to true, then the requester will be granted access if the file ID parameter refers to a shared drive and the requester is an administrator of the domain to which the shared drive belongs.

  • parameter enforceExpansiveAccess

    Whether the request should enforce expansive access rules.

  • parameter fileId

    The ID of the file or shared drive.

  • parameter permissionId

    The ID of the permission.

Sourceval get : ?base_url:string -> ?etag:string -> ?std_params:GapiService.StandardParameters.t -> ?custom_headers:GapiCore.Header.t list -> ?supportsAllDrives:bool -> ?supportsTeamDrives:bool -> ?useDomainAdminAccess:bool -> fileId:string -> permissionId:string -> GapiConversation.Session.t -> GapiDriveV3Model.Permission.t * GapiConversation.Session.t

Gets a permission by ID.

  • parameter base_url

    Service endpoint base URL (defaults to "https://www.googleapis.com/drive/v3/").

  • parameter etag

    Optional ETag.

  • parameter std_params

    Optional standard parameters.

  • parameter custom_headers

    Optional HTTP custom headers.

  • parameter supportsAllDrives

    Whether the requesting application supports both My Drives and shared drives.

  • parameter supportsTeamDrives

    Deprecated: Use `supportsAllDrives` instead.

  • parameter useDomainAdminAccess

    Issue the request as a domain administrator; if set to true, then the requester will be granted access if the file ID parameter refers to a shared drive and the requester is an administrator of the domain to which the shared drive belongs.

  • parameter fileId

    The ID of the file.

  • parameter permissionId

    The ID of the permission.

Sourceval list : ?base_url:string -> ?std_params:GapiService.StandardParameters.t -> ?custom_headers:GapiCore.Header.t list -> ?supportsAllDrives:bool -> ?supportsTeamDrives:bool -> ?useDomainAdminAccess:bool -> ?pageSize:int -> ?pageToken:string -> ?includePermissionsForView:string -> fileId:string -> GapiConversation.Session.t -> GapiDriveV3Model.PermissionList.t * GapiConversation.Session.t

Lists a file's or shared drive's permissions.

  • parameter base_url

    Service endpoint base URL (defaults to "https://www.googleapis.com/drive/v3/").

  • parameter std_params

    Optional standard parameters.

  • parameter custom_headers

    Optional HTTP custom headers.

  • parameter supportsAllDrives

    Whether the requesting application supports both My Drives and shared drives.

  • parameter supportsTeamDrives

    Deprecated: Use `supportsAllDrives` instead.

  • parameter useDomainAdminAccess

    Issue the request as a domain administrator; if set to true, then the requester will be granted access if the file ID parameter refers to a shared drive and the requester is an administrator of the domain to which the shared drive belongs.

  • parameter pageSize

    The maximum number of permissions to return per page. When not set for files in a shared drive, at most 100 results will be returned. When not set for files that are not in a shared drive, the entire list will be returned.

  • parameter pageToken

    The token for continuing a previous list request on the next page. This should be set to the value of 'nextPageToken' from the previous response.

  • parameter includePermissionsForView

    Specifies which additional view's permissions to include in the response. Only 'published' is supported.

  • parameter fileId

    The ID of the file or shared drive.

Sourceval update : ?base_url:string -> ?std_params:GapiService.StandardParameters.t -> ?custom_headers:GapiCore.Header.t list -> ?removeExpiration:bool -> ?supportsAllDrives:bool -> ?supportsTeamDrives:bool -> ?transferOwnership:bool -> ?useDomainAdminAccess:bool -> ?enforceExpansiveAccess:bool -> fileId:string -> permissionId:string -> GapiDriveV3Model.Permission.t -> GapiConversation.Session.t -> GapiDriveV3Model.Permission.t * GapiConversation.Session.t

Updates a permission with patch semantics. **Warning:** Concurrent permissions operations on the same file are not supported; only the last update is applied.

  • parameter base_url

    Service endpoint base URL (defaults to "https://www.googleapis.com/drive/v3/").

  • parameter std_params

    Optional standard parameters.

  • parameter custom_headers

    Optional HTTP custom headers.

  • parameter removeExpiration

    Whether to remove the expiration date.

  • parameter supportsAllDrives

    Whether the requesting application supports both My Drives and shared drives.

  • parameter supportsTeamDrives

    Deprecated: Use `supportsAllDrives` instead.

  • parameter transferOwnership

    Whether to transfer ownership to the specified user and downgrade the current owner to a writer. This parameter is required as an acknowledgement of the side effect.

  • parameter useDomainAdminAccess

    Issue the request as a domain administrator; if set to true, then the requester will be granted access if the file ID parameter refers to a shared drive and the requester is an administrator of the domain to which the shared drive belongs.

  • parameter enforceExpansiveAccess

    Whether the request should enforce expansive access rules.

  • parameter fileId

    The ID of the file or shared drive.

  • parameter permissionId

    The ID of the permission.