package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiGmailV1Model.VacationSettingsSource

Sourcetype t = {
  1. enableAutoReply : bool;
    (*

    Flag that controls whether Gmail automatically replies to messages.

    *)
  2. endTime : int64;
    (*

    An optional end time for sending auto-replies (epoch ms). When this is specified, Gmail will automatically reply only to messages that it receives before the end time. If both startTime and endTime are specified, startTime must precede endTime.

    *)
  3. responseBodyHtml : string;
    (*

    Response body in HTML format. Gmail will sanitize the HTML before storing it.

    *)
  4. responseBodyPlainText : string;
    (*

    Response body in plain text format.

    *)
  5. responseSubject : string;
    (*

    Optional text to prepend to the subject line in vacation responses. In order to enable auto-replies, either the response subject or the response body must be nonempty.

    *)
  6. restrictToContacts : bool;
    (*

    Flag that determines whether responses are sent to recipients who are not in the user's list of contacts.

    *)
  7. restrictToDomain : bool;
    (*

    Flag that determines whether responses are sent to recipients who are outside of the user's domain. This feature is only available for G Suite users.

    *)
  8. startTime : int64;
    (*

    An optional start time for sending auto-replies (epoch ms). When this is specified, Gmail will automatically reply only to messages that it receives after the start time. If both startTime and endTime are specified, startTime must precede endTime.

    *)
}
Sourceval enableAutoReply : (t, bool) GapiLens.t
Sourceval endTime : (t, int64) GapiLens.t
Sourceval responseBodyHtml : (t, string) GapiLens.t
Sourceval responseBodyPlainText : (t, string) GapiLens.t
Sourceval responseSubject : (t, string) GapiLens.t
Sourceval restrictToContacts : (t, bool) GapiLens.t
Sourceval restrictToDomain : (t, bool) GapiLens.t
Sourceval startTime : (t, int64) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t