package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiGmailV1Service.ScopeSource

Service Auth Scopes

Sourceval mail_google_com : string

Read, send, delete, and manage your email

Sourceval gmail_compose : string

Manage drafts and send emails

Sourceval gmail_insert : string

Insert mail into your mailbox

Sourceval gmail_labels : string

Manage mailbox labels

Sourceval gmail_metadata : string

View your email message metadata such as labels and headers, but not the email body

Sourceval gmail_modify : string

View and modify but not delete your email

Sourceval gmail_readonly : string

View your email messages and settings

Sourceval gmail_send : string

Send email on your behalf

Sourceval gmail_settings_basic : string

Manage your basic mail settings

Sourceval gmail_settings_sharing : string

Manage your sensitive mail settings, including who can manage your mail