package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiPagespeedonlineV1ServiceSource

Service definition for PageSpeed Insights API (v1).

Analyzes the performance of a web page and provides tailored suggestions to make that page faster..

For more information about this service, see the API Documentation.

Sourcemodule PagespeedapiResource : sig ... end