package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Person.ImageSource

Sourcetype t = {
  1. isDefault : bool;
    (*

    Whether the person's profile photo is the default one

    *)
  2. url : string;
    (*

    The URL of the person's profile photo. To resize the image and crop it to a square, append the query string ?sz=x, where x is the dimension in pixels of each side.

    *)
}
Sourceval isDefault : (t, bool) GapiLens.t
Sourceval url : (t, string) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list