package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module PeopleResource.CollectionSource

Sourcetype t =
  1. | Default
  2. | Connected
    (*

    The list of visible people in the authenticated user's circles who also use the requesting app. This list is limited to users who made their app activities visible to the authenticated user.

    *)
  3. | Visible
    (*

    The list of people who this user has added to one or more circles, limited to the circles visible to the requesting application.

    *)
  4. | Plusoners
    (*

    List all people who have +1'd this activity.

    *)
  5. | Resharers
    (*

    List all people who have reshared this activity.

    *)
Sourceval to_string : t -> string
Sourceval of_string : string -> t