package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Model.BasicChartAxisSource

Sourcetype t = {
  1. position : string;
    (*

    The position of this axis.

    *)
  2. title : string;
    (*

    The title of this axis. If set, this overrides any title inferred from headers of the data.

    *)
  3. format : TextFormat.t;
    (*

    The format of the title. Only valid if the axis is not associated with the domain. The link field is not supported.

    *)
  4. titleTextPosition : TextPosition.t;
    (*

    The axis title text position.

    *)
  5. viewWindowOptions : ChartAxisViewWindowOptions.t;
    (*

    The view window options for this axis.

    *)
}
Sourceval position : (t, string) GapiLens.t
Sourceval title : (t, string) GapiLens.t
Sourceval titleTextPosition : (t, TextPosition.t) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t