package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Model.BatchClearValuesResponseSource

Sourcetype t = {
  1. spreadsheetId : string;
    (*

    The spreadsheet the updates were applied to.

    *)
  2. clearedRanges : string list;
    (*

    The ranges that were cleared, in A1 notation. If the requests are for an unbounded range or a ranger larger than the bounds of the sheet, this is the actual ranges that were cleared, bounded to the sheet's limits.

    *)
}
Sourceval spreadsheetId : (t, string) GapiLens.t
Sourceval clearedRanges : (t, string list) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t