package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Model.BatchGetValuesByDataFilterRequestSource

Sourcetype t = {
  1. dataFilters : DataFilter.t list;
    (*

    The data filters used to match the ranges of values to retrieve. Ranges that match any of the specified data filters are included in the response.

    *)
  2. majorDimension : string;
    (*

    The major dimension that results should use. For example, if the spreadsheet data is: `A1=1,B1=2,A2=3,B2=4`, then a request that selects that range and sets `majorDimension=ROWS` returns `[[1,2],[3,4]]`, whereas a request that sets `majorDimension=COLUMNS` returns `[[1,3],[2,4]]`.

    *)
  3. valueRenderOption : string;
    (*

    How values should be represented in the output. The default render option is FORMATTED_VALUE.

    *)
  4. dateTimeRenderOption : string;
    (*

    How dates, times, and durations should be represented in the output. This is ignored if value_render_option is FORMATTED_VALUE. The default dateTime render option is SERIAL_NUMBER.

    *)
}
Sourceval dataFilters : (t, DataFilter.t list) GapiLens.t
Sourceval majorDimension : (t, string) GapiLens.t
Sourceval valueRenderOption : (t, string) GapiLens.t
Sourceval dateTimeRenderOption : (t, string) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t