package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Model.BigQueryDataSourceSpecSource

Sourcetype t = {
  1. projectId : string;
    (*

    The ID of a BigQuery enabled Google Cloud project with a billing account attached. For any queries executed against the data source, the project is charged.

    *)
  2. querySpec : BigQueryQuerySpec.t;
    (*

    A BigQueryQuerySpec.

    *)
  3. tableSpec : BigQueryTableSpec.t;
    (*

    A BigQueryTableSpec.

    *)
}
Sourceval projectId : (t, string) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t