package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Model.BubbleChartSpecSource

Sourcetype t = {
  1. legendPosition : string;
    (*

    Where the legend of the chart should be drawn.

    *)
  2. bubbleLabels : ChartData.t;
    (*

    The data containing the bubble labels. These do not need to be unique.

    *)
  3. domain : ChartData.t;
    (*

    The data containing the bubble x-values. These values locate the bubbles in the chart horizontally.

    *)
  4. series : ChartData.t;
    (*

    The data containing the bubble y-values. These values locate the bubbles in the chart vertically.

    *)
  5. groupIds : ChartData.t;
    (*

    The data containing the bubble group IDs. All bubbles with the same group ID are drawn in the same color. If bubble_sizes is specified then this field must also be specified but may contain blank values. This field is optional.

    *)
  6. bubbleSizes : ChartData.t;
    (*

    The data containing the bubble sizes. Bubble sizes are used to draw the bubbles at different sizes relative to each other. If specified, group_ids must also be specified. This field is optional.

    *)
  7. bubbleOpacity : float;
    (*

    The opacity of the bubbles between 0 and 1.0. 0 is fully transparent and 1 is fully opaque.

    *)
  8. bubbleBorderColor : Color.t;
    (*

    The bubble border color. Deprecated: Use bubble_border_color_style.

    *)
  9. bubbleBorderColorStyle : ColorStyle.t;
    (*

    The bubble border color. If bubble_border_color is also set, this field takes precedence.

    *)
  10. bubbleMaxRadiusSize : int;
    (*

    The max radius size of the bubbles, in pixels. If specified, the field must be a positive value.

    *)
  11. bubbleMinRadiusSize : int;
    (*

    The minimum radius size of the bubbles, in pixels. If specific, the field must be a positive value.

    *)
  12. bubbleTextStyle : TextFormat.t;
    (*

    The format of the text inside the bubbles. Strikethrough, underline, and link are not supported.

    *)
}
Sourceval legendPosition : (t, string) GapiLens.t
Sourceval bubbleLabels : (t, ChartData.t) GapiLens.t
Sourceval groupIds : (t, ChartData.t) GapiLens.t
Sourceval bubbleSizes : (t, ChartData.t) GapiLens.t
Sourceval bubbleOpacity : (t, float) GapiLens.t
Sourceval bubbleBorderColor : (t, Color.t) GapiLens.t
Sourceval bubbleBorderColorStyle : (t, ColorStyle.t) GapiLens.t
Sourceval bubbleMaxRadiusSize : (t, int) GapiLens.t
Sourceval bubbleMinRadiusSize : (t, int) GapiLens.t
Sourceval bubbleTextStyle : (t, TextFormat.t) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t