package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Model.CancelDataSourceRefreshRequestSource

Sourcetype t = {
  1. references : DataSourceObjectReferences.t;
    (*

    References to data source objects whose refreshes are to be cancelled.

    *)
  2. dataSourceId : string;
    (*

    Reference to a DataSource. If specified, cancels all associated data source object refreshes for this data source.

    *)
  3. isAll : bool;
    (*

    Cancels all existing data source object refreshes for all data sources in the spreadsheet.

    *)
}
Sourceval dataSourceId : (t, string) GapiLens.t
Sourceval isAll : (t, bool) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t