package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Model.DataSourceSource

Sourcetype t = {
  1. dataSourceId : string;
    (*

    The spreadsheet-scoped unique ID that identifies the data source. Example: 1080547365.

    *)
  2. spec : DataSourceSpec.t;
    (*

    The DataSourceSpec for the data source connected with this spreadsheet.

    *)
  3. calculatedColumns : DataSourceColumn.t list;
    (*

    All calculated columns in the data source.

    *)
  4. sheetId : int;
    (*

    The ID of the Sheet connected with the data source. The field cannot be changed once set. When creating a data source, an associated DATA_SOURCE sheet is also created, if the field is not specified, the ID of the created sheet will be randomly generated.

    *)
}
Sourceval dataSourceId : (t, string) GapiLens.t
Sourceval calculatedColumns : (t, DataSourceColumn.t list) GapiLens.t
Sourceval sheetId : (t, int) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t