package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Model.DataValidationRuleSource

Sourcetype t = {
  1. condition : BooleanCondition.t;
    (*

    The condition that data in the cell must match.

    *)
  2. inputMessage : string;
    (*

    A message to show the user when adding data to the cell.

    *)
  3. strict : bool;
    (*

    True if invalid data should be rejected.

    *)
  4. showCustomUi : bool;
    (*

    True if the UI should be customized based on the kind of condition. If true, "List" conditions will show a dropdown.

    *)
}
Sourceval inputMessage : (t, string) GapiLens.t
Sourceval strict : (t, bool) GapiLens.t
Sourceval showCustomUi : (t, bool) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t