package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Model.FindReplaceRequestSource

Sourcetype t = {
  1. find : string;
    (*

    The value to search.

    *)
  2. replacement : string;
    (*

    The value to use as the replacement.

    *)
  3. range : GridRange.t;
    (*

    The range to find/replace over.

    *)
  4. sheetId : int;
    (*

    The sheet to find/replace over.

    *)
  5. allSheets : bool;
    (*

    True to find/replace over all sheets.

    *)
  6. matchCase : bool;
    (*

    True if the search is case sensitive.

    *)
  7. matchEntireCell : bool;
    (*

    True if the find value should match the entire cell.

    *)
  8. searchByRegex : bool;
    (*

    True if the find value is a regex. The regular expression and replacement should follow Java regex rules at https://docs.oracle.com/javase/8/docs/api/java/util/regex/Pattern.html. The replacement string is allowed to refer to capturing groups. For example, if one cell has the contents `"Google Sheets"` and another has `"Google Docs"`, then searching for `"o.* (.*)"` with a replacement of `"$1 Rocks"` would change the contents of the cells to `"GSheets Rocks"` and `"GDocs Rocks"` respectively.

    *)
  9. includeFormulas : bool;
    (*

    True if the search should include cells with formulas. False to skip cells with formulas.

    *)
}
Sourceval find : (t, string) GapiLens.t
Sourceval replacement : (t, string) GapiLens.t
Sourceval sheetId : (t, int) GapiLens.t
Sourceval allSheets : (t, bool) GapiLens.t
Sourceval matchCase : (t, bool) GapiLens.t
Sourceval matchEntireCell : (t, bool) GapiLens.t
Sourceval searchByRegex : (t, bool) GapiLens.t
Sourceval includeFormulas : (t, bool) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t