package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Model.GetSpreadsheetByDataFilterRequestSource

Sourcetype t = {
  1. dataFilters : DataFilter.t list;
    (*

    The DataFilters used to select which ranges to retrieve from the spreadsheet.

    *)
  2. includeGridData : bool;
    (*

    True if grid data should be returned. This parameter is ignored if a field mask was set in the request.

    *)
  3. excludeTablesInBandedRanges : bool;
    (*

    True if tables should be excluded in the banded ranges. False if not set.

    *)
}
Sourceval dataFilters : (t, DataFilter.t list) GapiLens.t
Sourceval includeGridData : (t, bool) GapiLens.t
Sourceval excludeTablesInBandedRanges : (t, bool) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t