package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Model.GridPropertiesSource

Sourcetype t = {
  1. rowCount : int;
    (*

    The number of rows in the grid.

    *)
  2. columnCount : int;
    (*

    The number of columns in the grid.

    *)
  3. frozenRowCount : int;
    (*

    The number of rows that are frozen in the grid.

    *)
  4. frozenColumnCount : int;
    (*

    The number of columns that are frozen in the grid.

    *)
  5. hideGridlines : bool;
    (*

    True if the grid isn't showing gridlines in the UI.

    *)
  6. rowGroupControlAfter : bool;
    (*

    True if the row grouping control toggle is shown after the group.

    *)
  7. columnGroupControlAfter : bool;
    (*

    True if the column grouping control toggle is shown after the group.

    *)
}
Sourceval rowCount : (t, int) GapiLens.t
Sourceval columnCount : (t, int) GapiLens.t
Sourceval frozenRowCount : (t, int) GapiLens.t
Sourceval frozenColumnCount : (t, int) GapiLens.t
Sourceval hideGridlines : (t, bool) GapiLens.t
Sourceval rowGroupControlAfter : (t, bool) GapiLens.t
Sourceval columnGroupControlAfter : (t, bool) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t