package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Model.HistogramSeriesSource

Sourcetype t = {
  1. barColor : Color.t;
    (*

    The color of the column representing this series in each bucket. This field is optional. Deprecated: Use bar_color_style.

    *)
  2. barColorStyle : ColorStyle.t;
    (*

    The color of the column representing this series in each bucket. This field is optional. If bar_color is also set, this field takes precedence.

    *)
  3. data : ChartData.t;
    (*

    The data for this histogram series.

    *)
}
Sourceval barColor : (t, Color.t) GapiLens.t
Sourceval barColorStyle : (t, ColorStyle.t) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t