package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Model.IterativeCalculationSettingsSource

Sourcetype t = {
  1. maxIterations : int;
    (*

    When iterative calculation is enabled, the maximum number of calculation rounds to perform.

    *)
  2. convergenceThreshold : float;
    (*

    When iterative calculation is enabled and successive results differ by less than this threshold value, the calculation rounds stop.

    *)
}
Sourceval maxIterations : (t, int) GapiLens.t
Sourceval convergenceThreshold : (t, float) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t