package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Model.ManualRuleGroupSource

Sourcetype t = {
  1. groupName : ExtendedValue.t;
    (*

    The group name, which must be a string. Each group in a given ManualRule must have a unique group name.

    *)
  2. items : ExtendedValue.t list;
    (*

    The items in the source data that should be placed into this group. Each item may be a string, number, or boolean. Items may appear in at most one group within a given ManualRule. Items that do not appear in any group will appear on their own.

    *)
}
Sourceval items : (t, ExtendedValue.t list) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t