package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Model.PieChartSpecSource

Sourcetype t = {
  1. legendPosition : string;
    (*

    Where the legend of the pie chart should be drawn.

    *)
  2. domain : ChartData.t;
    (*

    The data that covers the domain of the pie chart.

    *)
  3. series : ChartData.t;
    (*

    The data that covers the one and only series of the pie chart.

    *)
  4. threeDimensional : bool;
    (*

    True if the pie is three dimensional.

    *)
  5. pieHole : float;
    (*

    The size of the hole in the pie chart.

    *)
}
Sourceval legendPosition : (t, string) GapiLens.t
Sourceval threeDimensional : (t, bool) GapiLens.t
Sourceval pieHole : (t, float) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t