package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Model.PivotValueSource

Sourcetype t = {
  1. sourceColumnOffset : int;
    (*

    The column offset of the source range that this value reads from. For example, if the source was `C10:E15`, a `sourceColumnOffset` of `0` means this value refers to column `C`, whereas the offset `1` would refer to column `D`.

    *)
  2. formula : string;
    (*

    A custom formula to calculate the value. The formula must start with an `=` character.

    *)
  3. dataSourceColumnReference : DataSourceColumnReference.t;
    (*

    The reference to the data source column that this value reads from.

    *)
  4. summarizeFunction : string;
    (*

    A function to summarize the value. If formula is set, the only supported values are SUM and CUSTOM. If sourceColumnOffset is set, then `CUSTOM` is not supported.

    *)
  5. name : string;
    (*

    A name to use for the value.

    *)
  6. calculatedDisplayType : string;
    (*

    If specified, indicates that pivot values should be displayed as the result of a calculation with another pivot value. For example, if calculated_display_type is specified as PERCENT_OF_GRAND_TOTAL, all the pivot values are displayed as the percentage of the grand total. In the Sheets editor, this is referred to as "Show As" in the value section of a pivot table.

    *)
}
Sourceval sourceColumnOffset : (t, int) GapiLens.t
Sourceval formula : (t, string) GapiLens.t
Sourceval dataSourceColumnReference : (t, DataSourceColumnReference.t) GapiLens.t
Sourceval summarizeFunction : (t, string) GapiLens.t
Sourceval name : (t, string) GapiLens.t
Sourceval calculatedDisplayType : (t, string) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t