package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Model.RefreshDataSourceRequestSource

Sourcetype t = {
  1. references : DataSourceObjectReferences.t;
    (*

    References to data source objects to refresh.

    *)
  2. dataSourceId : string;
    (*

    Reference to a DataSource. If specified, refreshes all associated data source objects for the data source.

    *)
  3. isAll : bool;
    (*

    Refreshes all existing data source objects in the spreadsheet.

    *)
  4. force : bool;
    (*

    Refreshes the data source objects regardless of the current state. If not set and a referenced data source object was in error state, the refresh will fail immediately.

    *)
}
Sourceval dataSourceId : (t, string) GapiLens.t
Sourceval isAll : (t, bool) GapiLens.t
Sourceval force : (t, bool) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t