package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Model.ScorecardChartSpecSource

Sourcetype t = {
  1. keyValueData : ChartData.t;
    (*

    The data for scorecard key value.

    *)
  2. baselineValueData : ChartData.t;
    (*

    The data for scorecard baseline value. This field is optional.

    *)
  3. aggregateType : string;
    (*

    The aggregation type for key and baseline chart data in scorecard chart. This field is not supported for data source charts. Use the ChartData.aggregateType field of the key_value_data or baseline_value_data instead for data source charts. This field is optional.

    *)
  4. keyValueFormat : KeyValueFormat.t;
    (*

    Formatting options for key value.

    *)
  5. baselineValueFormat : BaselineValueFormat.t;
    (*

    Formatting options for baseline value. This field is needed only if baseline_value_data is specified.

    *)
  6. scaleFactor : float;
    (*

    Value to scale scorecard key and baseline value. For example, a factor of 10 can be used to divide all values in the chart by 10. This field is optional.

    *)
  7. numberFormatSource : string;
    (*

    The number format source used in the scorecard chart. This field is optional.

    *)
  8. customFormatOptions : ChartCustomNumberFormatOptions.t;
    (*

    Custom formatting options for numeric key/baseline values in scorecard chart. This field is used only when number_format_source is set to CUSTOM. This field is optional.

    *)
}
Sourceval keyValueData : (t, ChartData.t) GapiLens.t
Sourceval baselineValueData : (t, ChartData.t) GapiLens.t
Sourceval aggregateType : (t, string) GapiLens.t
Sourceval keyValueFormat : (t, KeyValueFormat.t) GapiLens.t
Sourceval baselineValueFormat : (t, BaselineValueFormat.t) GapiLens.t
Sourceval scaleFactor : (t, float) GapiLens.t
Sourceval numberFormatSource : (t, string) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t