package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Model.SlicerSpecSource

Sourcetype t = {
  1. dataRange : GridRange.t;
    (*

    The data range of the slicer.

    *)
  2. filterCriteria : FilterCriteria.t;
    (*

    The filtering criteria of the slicer.

    *)
  3. columnIndex : int;
    (*

    The zero-based column index in the data table on which the filter is applied to.

    *)
  4. applyToPivotTables : bool;
    (*

    True if the filter should apply to pivot tables. If not set, default to `True`.

    *)
  5. title : string;
    (*

    The title of the slicer.

    *)
  6. textFormat : TextFormat.t;
    (*

    The text format of title in the slicer. The link field is not supported.

    *)
  7. backgroundColor : Color.t;
    (*

    The background color of the slicer. Deprecated: Use background_color_style.

    *)
  8. backgroundColorStyle : ColorStyle.t;
    (*

    The background color of the slicer. If background_color is also set, this field takes precedence.

    *)
  9. horizontalAlignment : string;
    (*

    The horizontal alignment of title in the slicer. If unspecified, defaults to `LEFT`

    *)
}
Sourceval dataRange : (t, GridRange.t) GapiLens.t
Sourceval filterCriteria : (t, FilterCriteria.t) GapiLens.t
Sourceval columnIndex : (t, int) GapiLens.t
Sourceval applyToPivotTables : (t, bool) GapiLens.t
Sourceval title : (t, string) GapiLens.t
Sourceval textFormat : (t, TextFormat.t) GapiLens.t
Sourceval backgroundColor : (t, Color.t) GapiLens.t
Sourceval backgroundColorStyle : (t, ColorStyle.t) GapiLens.t
Sourceval horizontalAlignment : (t, string) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t