package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Model.SpreadsheetPropertiesSource

Sourcetype t = {
  1. title : string;
    (*

    The title of the spreadsheet.

    *)
  2. locale : string;
    (*

    The locale of the spreadsheet in one of the following formats: * an ISO 639-1 language code such as `en` * an ISO 639-2 language code such as `fil`, if no 639-1 code exists * a combination of the ISO language code and country code, such as `en_US` Note: when updating this field, not all locales/languages are supported.

    *)
  3. autoRecalc : string;
    (*

    The amount of time to wait before volatile functions are recalculated.

    *)
  4. timeZone : string;
    (*

    The time zone of the spreadsheet, in CLDR format such as `America/New_York`. If the time zone isn't recognized, this may be a custom time zone such as `GMT-07:00`.

    *)
  5. defaultFormat : CellFormat.t;
    (*

    The default format of all cells in the spreadsheet. CellData.effectiveFormat will not be set if the cell's format is equal to this default format. This field is read-only.

    *)
  6. iterativeCalculationSettings : IterativeCalculationSettings.t;
    (*

    Determines whether and how circular references are resolved with iterative calculation. Absence of this field means that circular references result in calculation errors.

    *)
  7. spreadsheetTheme : SpreadsheetTheme.t;
    (*

    Theme applied to the spreadsheet.

    *)
  8. importFunctionsExternalUrlAccessAllowed : bool;
    (*

    Whether to allow external URL access for image and import functions. Read only when true. When false, you can set to true. This value will be bypassed and always return true if the admin has enabled the [allowlisting feature](https://support.google.com/a?p=url_allowlist).

    *)
}
Sourceval title : (t, string) GapiLens.t
Sourceval locale : (t, string) GapiLens.t
Sourceval autoRecalc : (t, string) GapiLens.t
Sourceval timeZone : (t, string) GapiLens.t
Sourceval defaultFormat : (t, CellFormat.t) GapiLens.t
Sourceval iterativeCalculationSettings : (t, IterativeCalculationSettings.t) GapiLens.t
Sourceval spreadsheetTheme : (t, SpreadsheetTheme.t) GapiLens.t
Sourceval importFunctionsExternalUrlAccessAllowed : (t, bool) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t