package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Model.TableRowsPropertiesSource

Sourcetype t = {
  1. headerColorStyle : ColorStyle.t;
    (*

    The color of the header row. If this field is set, the header row is filled with the specified color. Otherwise, the header row is filled with a default color.

    *)
  2. firstBandColorStyle : ColorStyle.t;
    (*

    The first color that is alternating. If this field is set, the first banded row is filled with the specified color. Otherwise, the first banded row is filled with a default color.

    *)
  3. secondBandColorStyle : ColorStyle.t;
    (*

    The second color that is alternating. If this field is set, the second banded row is filled with the specified color. Otherwise, the second banded row is filled with a default color.

    *)
  4. footerColorStyle : ColorStyle.t;
    (*

    The color of the last row. If this field is not set a footer is not added, the last row is filled with either first_band_color_style or second_band_color_style, depending on the color of the previous row. If updating an existing table without a footer to have a footer, the range will be expanded by 1 row. If updating an existing table with a footer and removing a footer, the range will be shrunk by 1 row.

    *)
}
Sourceval headerColorStyle : (t, ColorStyle.t) GapiLens.t
Sourceval firstBandColorStyle : (t, ColorStyle.t) GapiLens.t
Sourceval secondBandColorStyle : (t, ColorStyle.t) GapiLens.t
Sourceval footerColorStyle : (t, ColorStyle.t) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t