package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Model.TimeOfDaySource

Sourcetype t = {
  1. hours : int;
    (*

    Hours of a day in 24 hour format. Must be greater than or equal to 0 and typically must be less than or equal to 23. An API may choose to allow the value "24:00:00" for scenarios like business closing time.

    *)
  2. minutes : int;
    (*

    Minutes of an hour. Must be greater than or equal to 0 and less than or equal to 59.

    *)
  3. seconds : int;
    (*

    Seconds of a minute. Must be greater than or equal to 0 and typically must be less than or equal to 59. An API may allow the value 60 if it allows leap-seconds.

    *)
  4. nanos : int;
    (*

    Fractions of seconds, in nanoseconds. Must be greater than or equal to 0 and less than or equal to 999,999,999.

    *)
}
Sourceval hours : (t, int) GapiLens.t
Sourceval minutes : (t, int) GapiLens.t
Sourceval seconds : (t, int) GapiLens.t
Sourceval nanos : (t, int) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t