package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Model.TreemapChartSpecSource

Sourcetype t = {
  1. labels : ChartData.t;
    (*

    The data that contains the treemap cell labels.

    *)
  2. parentLabels : ChartData.t;
    (*

    The data the contains the treemap cells' parent labels.

    *)
  3. sizeData : ChartData.t;
    (*

    The data that determines the size of each treemap data cell. This data is expected to be numeric. The cells corresponding to non-numeric or missing data will not be rendered. If color_data is not specified, this data is used to determine data cell background colors as well.

    *)
  4. colorData : ChartData.t;
    (*

    The data that determines the background color of each treemap data cell. This field is optional. If not specified, size_data is used to determine background colors. If specified, the data is expected to be numeric. color_scale will determine how the values in this data map to data cell background colors.

    *)
  5. textFormat : TextFormat.t;
    (*

    The text format for all labels on the chart. The link field is not supported.

    *)
  6. levels : int;
    (*

    The number of data levels to show on the treemap chart. These levels are interactive and are shown with their labels. Defaults to 2 if not specified.

    *)
  7. hintedLevels : int;
    (*

    The number of additional data levels beyond the labeled levels to be shown on the treemap chart. These levels are not interactive and are shown without their labels. Defaults to 0 if not specified.

    *)
  8. minValue : float;
    (*

    The minimum possible data value. Cells with values less than this will have the same color as cells with this value. If not specified, defaults to the actual minimum value from color_data, or the minimum value from size_data if color_data is not specified.

    *)
  9. maxValue : float;
    (*

    The maximum possible data value. Cells with values greater than this will have the same color as cells with this value. If not specified, defaults to the actual maximum value from color_data, or the maximum value from size_data if color_data is not specified.

    *)
  10. headerColor : Color.t;
    (*

    The background color for header cells. Deprecated: Use header_color_style.

    *)
  11. headerColorStyle : ColorStyle.t;
    (*

    The background color for header cells. If header_color is also set, this field takes precedence.

    *)
  12. colorScale : TreemapChartColorScale.t;
    (*

    The color scale for data cells in the treemap chart. Data cells are assigned colors based on their color values. These color values come from color_data, or from size_data if color_data is not specified. Cells with color values less than or equal to min_value will have minValueColor as their background color. Cells with color values greater than or equal to max_value will have maxValueColor as their background color. Cells with color values between min_value and max_value will have background colors on a gradient between minValueColor and maxValueColor, the midpoint of the gradient being midValueColor. Cells with missing or non-numeric color values will have noDataColor as their background color.

    *)
  13. hideTooltips : bool;
    (*

    True to hide tooltips.

    *)
}
Sourceval parentLabels : (t, ChartData.t) GapiLens.t
Sourceval sizeData : (t, ChartData.t) GapiLens.t
Sourceval colorData : (t, ChartData.t) GapiLens.t
Sourceval textFormat : (t, TextFormat.t) GapiLens.t
Sourceval levels : (t, int) GapiLens.t
Sourceval hintedLevels : (t, int) GapiLens.t
Sourceval minValue : (t, float) GapiLens.t
Sourceval maxValue : (t, float) GapiLens.t
Sourceval headerColor : (t, Color.t) GapiLens.t
Sourceval headerColorStyle : (t, ColorStyle.t) GapiLens.t
Sourceval hideTooltips : (t, bool) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t