package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Model.UnmergeCellsRequestSource

Sourcetype t = {
  1. range : GridRange.t;
    (*

    The range within which all cells should be unmerged. If the range spans multiple merges, all will be unmerged. The range must not partially span any merge.

    *)
}
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t