package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Model.WaterfallChartSpecSource

Sourcetype t = {
  1. domain : WaterfallChartDomain.t;
    (*

    The domain data (horizontal axis) for the waterfall chart.

    *)
  2. series : WaterfallChartSeries.t list;
    (*

    The data this waterfall chart is visualizing.

    *)
  3. stackedType : string;
    (*

    The stacked type.

    *)
  4. firstValueIsTotal : bool;
    (*

    True to interpret the first value as a total.

    *)
  5. hideConnectorLines : bool;
    (*

    True to hide connector lines between columns.

    *)
  6. connectorLineStyle : LineStyle.t;
    (*

    The line style for the connector lines.

    *)
  7. totalDataLabel : DataLabel.t;
    (*

    Controls whether to display additional data labels on stacked charts which sum the total value of all stacked values at each value along the domain axis. stacked_type must be STACKED and neither CUSTOM nor placement can be set on the total_data_label.

    *)
}
Sourceval stackedType : (t, string) GapiLens.t
Sourceval firstValueIsTotal : (t, bool) GapiLens.t
Sourceval hideConnectorLines : (t, bool) GapiLens.t
Sourceval connectorLineStyle : (t, LineStyle.t) GapiLens.t
Sourceval totalDataLabel : (t, DataLabel.t) GapiLens.t
Sourceval empty : t
Sourceval render : t -> GapiJson.json_data_model list
Sourceval to_data_model : t -> GapiJson.json_data_model
Sourceval of_data_model : GapiJson.json_data_model -> t