package gapi-ocaml

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module GapiSheetsV4Service.SpreadsheetsResourceSource

Sourcemodule Sheets : sig ... end
Sourcemodule DeveloperMetadata : sig ... end
Sourcemodule Values : sig ... end

Creates a spreadsheet, returning the newly created spreadsheet.

  • parameter base_url

    Service endpoint base URL (defaults to "https://sheets.googleapis.com/").

  • parameter std_params

    Optional standard parameters.

  • parameter custom_headers

    Optional HTTP custom headers.

Sourceval get : ?base_url:string -> ?etag:string -> ?std_params:GapiService.StandardParameters.t -> ?custom_headers:GapiCore.Header.t list -> ?ranges:string list -> ?includeGridData:bool -> ?excludeTablesInBandedRanges:bool -> spreadsheetId:string -> GapiConversation.Session.t -> GapiSheetsV4Model.Spreadsheet.t * GapiConversation.Session.t

Returns the spreadsheet at the given ID. The caller must specify the spreadsheet ID. By default, data within grids is not returned. You can include grid data in one of 2 ways: * Specify a [field mask](https://developers.google.com/workspace/sheets/api/guides/field-masks) listing your desired fields using the `fields` URL parameter in HTTP * Set the includeGridData URL parameter to true. If a field mask is set, the `includeGridData` parameter is ignored For large spreadsheets, as a best practice, retrieve only the specific spreadsheet fields that you want. To retrieve only subsets of spreadsheet data, use the ranges URL parameter. Ranges are specified using [A1 notation](https://developers.google.com/workspace/sheets/api/guides/concepts#cell). You can define a single cell (for example, `A1`) or multiple cells (for example, `A1:D5`). You can also get cells from other sheets within the same spreadsheet (for example, `Sheet2!A1:C4`) or retrieve multiple ranges at once (for example, `?ranges=A1:D5&ranges=Sheet2!A1:C4`). Limiting the range returns only the portions of the spreadsheet that intersect the requested ranges.

  • parameter base_url

    Service endpoint base URL (defaults to "https://sheets.googleapis.com/").

  • parameter etag

    Optional ETag.

  • parameter std_params

    Optional standard parameters.

  • parameter custom_headers

    Optional HTTP custom headers.

  • parameter ranges

    The ranges to retrieve from the spreadsheet.

  • parameter includeGridData

    True if grid data should be returned. This parameter is ignored if a field mask was set in the request.

  • parameter excludeTablesInBandedRanges

    True if tables should be excluded in the banded ranges. False if not set.

  • parameter spreadsheetId

    The spreadsheet to request.

Returns the spreadsheet at the given ID. The caller must specify the spreadsheet ID. This method differs from GetSpreadsheet in that it allows selecting which subsets of spreadsheet data to return by specifying a dataFilters parameter. Multiple DataFilters can be specified. Specifying one or more data filters returns the portions of the spreadsheet that intersect ranges matched by any of the filters. By default, data within grids is not returned. You can include grid data one of 2 ways: * Specify a [field mask](https://developers.google.com/workspace/sheets/api/guides/field-masks) listing your desired fields using the `fields` URL parameter in HTTP * Set the includeGridData parameter to true. If a field mask is set, the `includeGridData` parameter is ignored For large spreadsheets, as a best practice, retrieve only the specific spreadsheet fields that you want.

  • parameter base_url

    Service endpoint base URL (defaults to "https://sheets.googleapis.com/").

  • parameter std_params

    Optional standard parameters.

  • parameter custom_headers

    Optional HTTP custom headers.

  • parameter spreadsheetId

    The spreadsheet to request.

Applies one or more updates to the spreadsheet. Each request is validated before being applied. If any request is not valid then the entire request will fail and nothing will be applied. Some requests have replies to give you some information about how they are applied. The replies will mirror the requests. For example, if you applied 4 updates and the 3rd one had a reply, then the response will have 2 empty replies, the actual reply, and another empty reply, in that order. Due to the collaborative nature of spreadsheets, it is not guaranteed that the spreadsheet will reflect exactly your changes after this completes, however it is guaranteed that the updates in the request will be applied together atomically. Your changes may be altered with respect to collaborator changes. If there are no collaborators, the spreadsheet should reflect your changes.

  • parameter base_url

    Service endpoint base URL (defaults to "https://sheets.googleapis.com/").

  • parameter std_params

    Optional standard parameters.

  • parameter custom_headers

    Optional HTTP custom headers.

  • parameter spreadsheetId

    The spreadsheet to apply the updates to.